@@ -579,7 +579,7 @@ sub is_perl_file
 
     return if -l $file;
     return unless -f $file;
-    return if any { /^\./ } grep { length } File::Spec->splitdir($file);
+    return if any { /^\.pls-tmp/ } grep { length } File::Spec->splitdir($file);
     return if $file =~ /\.t$/;
 
     return 1 if $file =~ /\.p[lm]$/;
