@@ -6,7 +6,7 @@ use warnings;
 use parent 'PLS::Server::Request';
 
 use PLS::Parser::Document;
-use PLS::Server::Request::Diagnostics::PublishDiagnostics;
+use PLS::Server::Request::TextDocument::PublishDiagnostics;
 
 =head1 NAME
 
@@ -24,7 +24,7 @@ sub service
     my ($self, $server) = @_;
 
     my $uri = $self->{params}{textDocument}{uri};
-    $server->send_server_request(PLS::Server::Request::Diagnostics::PublishDiagnostics->new(uri => $uri));
+    $server->send_server_request(PLS::Server::Request::TextDocument::PublishDiagnostics->new(uri => $uri));
 
     return;
 } ## end sub service
